@@ -1,73 +1,69 @@
 package Mozilla::PublicSuffix;
 
 use strict;
-use warnings FATAL => "all";
+use warnings FATAL => 'all';
 use utf8;
-use Exporter "import";
+use Exporter qw(import);
 use URI::_idna;
 
 our @EXPORT_OK = qw(public_suffix);
 
-our $VERSION = 'v0.1.17'; # VERSION
+our $VERSION = 'v0.1.18'; # VERSION
 # ABSTRACT: Get a domain name's public suffix via the Mozilla Public Suffix List
 
 my $dn_re = do {
-    my $alf = "[[:alpha:]]";
-    my $aln = "[[:alnum:]]";
-    my $anh = "[[:alnum:]-]";
-    my $re_str = join(
-        "",
-        "(?:$aln(?:(?:$anh){0,61}$aln)?",
-        "(?:\\.$aln(?:(?:$anh){0,61}$aln)?)*)"
-    );
+    my $aln = '[[:alnum:]]';
+    my $anh = '[[:alnum:]-]';
+    my $re_str = "(?:$aln(?:(?:$anh){0,61}$aln)?"
+               . "(?:\\.$aln(?:(?:$anh){0,61}$aln)?)*)";
+
     qr/^$re_str$/;
 };
 sub public_suffix {
+    my $string = shift;
 
     # Decode domains in punycode form:
-    my $domain = defined($_[0]) && ref($_[0]) eq ""
-        ? index($_[0], "xn--") == -1
-            ? lc $_[0]
-            : eval { lc URI::_idna::decode($_[0]) }
-        : "";
-
-    # Return early if domain is not well-formed:
-    return unless $domain =~ $dn_re;
+    my $domain = defined($string) && ref($string) eq ''
+        ? index($string, 'xn--') == -1
+            ? lc $string
+            : eval { lc URI::_idna::decode($string) }
+        : '';
 
     # Search using the full domain and a substring consisting of its lowest
-    # levels:
-    return _find_rule($domain);
+    # levels, or return early (undef in scalar context) if the domain name is
+    # not well-formed according to RFC 1123:
+    return $domain =~ $dn_re ? _find_rule($domain) : ( );
 }
 
 my %rules = qw();
 
 # Right-hand side of a domain name:
 sub _rhs {
-    my ($domain) = @_;
-    return substr($domain, index($domain, ".") + 1);
+    my $domain = shift;
+    return substr($domain, index($domain, '.') + 1);
 }
 
 sub _find_rule {
-    my ($domain) = @_;
+    my $domain = shift;
     my $rhs = _rhs($domain);
     my $rule = $rules{$domain};
 
     return do {
         # Test for rule match with full domain:
-        if (defined $rule) {
+        if ( defined $rule ) {
             # An identity rule match means the full domain is the public suffix:
-            if ( $rule eq "i" ) { $domain } # return undef in scalar context
+            if ( $rule eq 'i' ) { $domain } # return undef in scalar context
 
-            # If a wilcard rule matches the full domain, fail out:
-            elsif ( $rule eq "w" ) { () }
+            # Fail out if a wilcard rule matches the full domain:
+            elsif ( $rule eq 'w' ) { () }
 
             # An exception rule means the right-hand side is the public suffix:
             else { $rhs }
         }
 
-        # Fail if no match found and the full domain and right-hand side are
+        # Fail out if no match found and the full domain and right-hand side are
         # identical:
-        elsif ( $domain eq $rhs ) { () } # return undef in scalar context
+        elsif ( $domain eq $rhs ) { () }
 
         # No match found with the full domain, but there are more levels of the
         # domain to check:
@@ -79,21 +75,19 @@ sub _find_rule {
 
                 # If a wildcard rule matches the right-hand side, the full
                 # domain is the public suffix:
-                if ( $rrule eq "w" ) { $domain }
+                if ( $rrule eq 'w' ) { $domain }
 
                 # An identity rule match means it's the right-hand side:
-                elsif ( $rrule eq "i" ) { $rhs }
+                elsif ( $rrule eq 'i' ) { $rhs }
 
                 # An exception rule match means it's the right-hand side of the
                 # right-hand side:
                 else { _rhs($rhs) }
             }
 
-            # Recurse with the right-hand side as the full domain, and the old
-            # right-hand side sans its lowest domain level as the new right-hand
-            # side:
+            # Try again with the right-hand side as the full domain:
             else {
-                _find_rule($rhs, _rhs($rhs));
+                _find_rule($rhs);
             }
         }
     }
@@ -108,14 +102,14 @@ Mozilla::PublicSuffix - Get a domain name's public suffix via the Mozilla Public
 
 =head1 SYNOPSIS
 
-    use feature "say";
-    use Mozilla::PublicSuffix "public_suffix";
+    use feature qw(say);
+    use Mozilla::PublicSuffix qw(public_suffix);
 
-    say public_suffix("org");       # "org"
-    say public_suffix("perl.org");  # "org"
-    say public_suffix("perl.orc");  # undef
-    say public_suffix("ga.gov.au"); # "gov.au"
-    say public_suffix("ga.goo.au"); # undef
+    say public_suffix('org');       # 'org'
+    say public_suffix('perl.org');  # 'org'
+    say public_suffix('perl.orc');  # undef
+    say public_suffix('ga.gov.au'); # 'gov.au'
+    say public_suffix('ga.goo.au'); # undef
 
 =head1 DESCRIPTION
 
@@ -133,9 +127,9 @@ Suffix List is a list of all known public suffixes.
 
 A copy of the official list is bundled with the distribution. As the official
 list continues to be updated, the bundled copy will inevitably fall out of date.
-Therefore, if the bundled copy of found to be over thirty days old, this
-distribution's installer provides the option to check for a new version of the
-list and download/use it if one is found.
+Aside from new releases always including the latest version of the list, this
+distribution's installer provides the option (defaults to "No") to check for a
+new version of the list and download/use it if one is found.
 
 =head1 FUNCTIONS
 
@@ -144,7 +138,8 @@ list and download/use it if one is found.
 =item public_suffix($domain)
 
 Exported on request. Simply returns the public suffix of the passed domain name,
-or C<undef> if the public suffix is not found.
+or C<undef> if either the domain name is not well-formed or the public suffix is
+not found.
 
 =back
 
